
class TruffleFile:
    def __init__(self, path: str, name: str):
        self.path = path
        self.name = name


class TruffleImage:
    def __init__(self, path: str, name: str):
        self.path = path
        self.name = name

