# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: sdk.proto
# Protobuf Python Version: 5.28.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    28,
    1,
    '',
    'sdk.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\tsdk.proto\x12\x03sdk\"\xa9\x03\n\x10ModelDescription\x12\x10\n\x08model_id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x38\n\x0c\x63\x61pabilities\x18\x04 \x01(\x0b\x32\".sdk.ModelDescription.Capabilities\x12-\n\x04type\x18\x05 \x01(\x0e\x32\x1f.sdk.ModelDescription.ModelType\x12\x10\n\x08is_local\x18\x06 \x01(\x08\x1a\x7f\n\x0c\x43\x61pabilities\x12\x19\n\x11structured_output\x18\x01 \x01(\x08\x12\x15\n\rimage_support\x18\x02 \x01(\x08\x12\x10\n\x08reasoner\x18\x03 \x01(\x08\x12\x18\n\x10world_domination\x18\x04 \x01(\x08\x12\x11\n\tlanguages\x18\x05 \x03(\t\"d\n\tModelType\x12\x15\n\x11MODEL_UNSPECIFIED\x10\x00\x12\x0f\n\x0bMODEL_SMART\x10\x01\x12\x0e\n\nMODEL_FAST\x10\x02\x12\x10\n\x0cMODEL_VISION\x10\x03\x12\r\n\tMODEL_AGI\x10\x04\"\x12\n\x10GetModelsRequest\":\n\x11GetModelsResponse\x12%\n\x06models\x18\x01 \x03(\x0b\x32\x15.sdk.ModelDescription\";\n\x0eGlobalsRequest\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\x05value\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_value\" \n\x0fGlobalsResponse\x12\r\n\x05value\x18\x01 \x01(\t\"\x83\x01\n\x11SystemToolRequest\x12\x11\n\ttool_name\x18\x01 \x01(\t\x12.\n\x04\x61rgs\x18\x02 \x03(\x0b\x32 .sdk.SystemToolRequest.ArgsEntry\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xab\x01\n\x12SystemToolResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x35\n\x07results\x18\x02 \x03(\x0b\x32$.sdk.SystemToolResponse.ResultsEntry\x12\x12\n\x05\x65rror\x18\x03 \x01(\tH\x00\x88\x01\x01\x1a.\n\x0cResultsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06_error\"7\n\x0bSDKResponse\x12\n\n\x02ok\x18\x01 \x01(\x08\x12\x12\n\x05\x65rror\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\x08\n\x06_error\"1\n\x11ToolUpdateRequest\x12\x1c\n\x14\x66riendly_description\x18\x01 \x01(\t\".\n\x0bUserRequest\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"V\n\x0cUserResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x12\n\x05\x65rror\x18\x02 \x01(\tH\x00\x88\x01\x01\x12\x16\n\x0e\x61ttached_files\x18\x03 \x03(\tB\x08\n\x06_error\"\xac\x01\n\x16GenerateResponseFormat\x12:\n\x06\x66ormat\x18\x01 \x01(\x0e\x32*.sdk.GenerateResponseFormat.ResponseFormat\x12\x13\n\x06schema\x18\x02 \x01(\tH\x00\x88\x01\x01\"6\n\x0eResponseFormat\x12\x11\n\rRESPONSE_TEXT\x10\x00\x12\x11\n\rRESPONSE_JSON\x10\x01\x42\t\n\x07_schema\"\x9e\x01\n\x07\x43ontent\x12\x1f\n\x04role\x18\x01 \x01(\x0e\x32\x11.sdk.Content.Role\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x11\n\x04\x64\x61ta\x18\x03 \x01(\x0cH\x00\x88\x01\x01\"E\n\x04Role\x12\x10\n\x0cROLE_INVALID\x10\x00\x12\r\n\tROLE_USER\x10\x01\x12\x0b\n\x07ROLE_AI\x10\x02\x12\x0f\n\x0bROLE_SYSTEM\x10\x03\x42\x07\n\x05_data\"(\n\x07\x43ontext\x12\x1d\n\x07history\x18\x01 \x03(\x0b\x32\x0c.sdk.Content\"\xd7\x01\n\x0fGenerateRequest\x12\x11\n\x07message\x18\x01 \x01(\tH\x00\x12\x1f\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x0c.sdk.ContextH\x00\x12\x12\n\nmax_tokens\x18\x03 \x01(\x05\x12\x10\n\x08model_id\x18\x04 \x01(\x05\x12\x18\n\x0btemperature\x18\x05 \x01(\x02H\x01\x88\x01\x01\x12-\n\x03\x66mt\x18\x06 \x01(\x0b\x32\x1b.sdk.GenerateResponseFormatH\x02\x88\x01\x01\x42\t\n\x07\x63ontentB\x0e\n\x0c_temperatureB\x06\n\x04_fmt\"X\n\x0fGenerationUsage\x12\x15\n\rprompt_tokens\x18\x01 \x01(\x05\x12\x19\n\x11\x63ompletion_tokens\x18\x02 \x01(\x05\x12\x13\n\x0b\x61pprox_time\x18\x03 \x01(\x05\"\xb9\x01\n\rTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\x12\x35\n\rfinish_reason\x18\x02 \x01(\x0e\x32\x19.sdk.GenerateFinishReasonH\x00\x88\x01\x01\x12(\n\x05usage\x18\x03 \x01(\x0b\x32\x14.sdk.GenerationUsageH\x01\x88\x01\x01\x12\x12\n\x05\x65rror\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_finish_reasonB\x08\n\x06_usageB\x08\n\x06_error\"\xbf\x01\n\x10GenerateResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x35\n\rfinish_reason\x18\x02 \x01(\x0e\x32\x19.sdk.GenerateFinishReasonH\x00\x88\x01\x01\x12(\n\x05usage\x18\x03 \x01(\x0b\x32\x14.sdk.GenerationUsageH\x01\x88\x01\x01\x12\x12\n\x05\x65rror\x18\x04 \x01(\tH\x02\x88\x01\x01\x42\x10\n\x0e_finish_reasonB\x08\n\x06_usageB\x08\n\x06_error\".\n\x0fSortedEmbedding\x12\x0c\n\x04text\x18\x01 \x01(\t\x12\r\n\x05score\x18\x02 \x01(\x02\"6\n\rEmbedResponse\x12%\n\x07results\x18\x01 \x03(\x0b\x32\x14.sdk.SortedEmbedding\"0\n\x0c\x45mbedRequest\x12\x11\n\tdocuments\x18\x01 \x03(\t\x12\r\n\x05query\x18\x02 \x01(\t\"\xc8\x05\n\x11\x41ppUploadProgress\x12/\n\x04step\x18\x01 \x01(\x0e\x32!.sdk.AppUploadProgress.UploadStep\x12\x10\n\x08progress\x18\x02 \x01(\x05\x12/\n\x04type\x18\x03 \x01(\x0e\x32!.sdk.AppUploadProgress.UploadType\x12\x13\n\x0blatest_logs\x18\x04 \x01(\t\x12\x14\n\x07substep\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x39\n\x05\x65rror\x18\n \x01(\x0b\x32%.sdk.AppUploadProgress.AppUploadErrorH\x01\x88\x01\x01\x1a#\n\x0e\x41ppUploadError\x12\x11\n\traw_error\x18\x01 \x01(\t\"\xba\x02\n\nUploadStep\x12\x10\n\x0cSTEP_UNKNOWN\x10\x00\x12\x16\n\x12STEP_UPLOAD_BUNDLE\x10\x01\x12\x16\n\x12STEP_VERIFY_BUNDLE\x10\x02\x12\x19\n\x15STEP_SYNC_WITH_SERVER\x10\x03\x12\x15\n\x11STEP_WRITE_BUNDLE\x10\x04\x12\x19\n\x15STEP_CREATE_CONTAINER\x10\x05\x12\x1d\n\x19STEP_INSTALL_DEPENDENCIES\x10\x06\x12!\n\x1dSTEP_GENERATE_CLASSIFIER_DATA\x10\x07\x12\x17\n\x13STEP_SAVE_CONTAINER\x10\x08\x12\x15\n\x11STEP_GATHER_TOOLS\x10\t\x12\x17\n\x13STEP_VERIFY_INSTALL\x10\n\x12\x12\n\x0eSTEP_INSTALLED\x10\x0b\"[\n\nUploadType\x12\x1c\n\x18UPLOAD_TYPE_UNDETERMINED\x10\x00\x12\x17\n\x13UPLOAD_TYPE_INSTALL\x10\x01\x12\x16\n\x12UPLOAD_TYPE_UPDATE\x10\x02\x42\n\n\x08_substepB\x08\n\x06_errorJ\x04\x08\x06\x10\n*\x98\x01\n\x14GenerateFinishReason\x12\x1d\n\x19\x46INISH_REASON_UNSPECIFIED\x10\x00\x12\x18\n\x14\x46INISH_REASON_LENGTH\x10\x01\x12\x16\n\x12\x46INISH_REASON_STOP\x10\x02\x12\x17\n\x13\x46INISH_REASON_ERROR\x10\x03\x12\x16\n\x12\x46INISH_REASON_USER\x10\x04*K\n\x0bTruffleType\x12\x17\n\x13TRUFFLE_UNSPECIFIED\x10\x00\x12\x11\n\rTRUFFLE_IMAGE\x10\x01\x12\x10\n\x0cTRUFFLE_FILE\x10\x02\x32\xc7\x03\n\nTruffleSDK\x12\x33\n\x05Infer\x12\x14.sdk.GenerateRequest\x1a\x12.sdk.TokenResponse0\x01\x12\x38\n\tInferSync\x12\x14.sdk.GenerateRequest\x1a\x15.sdk.GenerateResponse\x12:\n\tGetModels\x12\x15.sdk.GetModelsRequest\x1a\x16.sdk.GetModelsResponse\x12.\n\x05\x45mbed\x12\x11.sdk.EmbedRequest\x1a\x12.sdk.EmbedResponse\x12.\n\x07\x41skUser\x12\x10.sdk.UserRequest\x1a\x11.sdk.UserResponse\x12\x36\n\nToolUpdate\x12\x16.sdk.ToolUpdateRequest\x1a\x10.sdk.SDKResponse\x12=\n\nSystemTool\x12\x16.sdk.SystemToolRequest\x1a\x17.sdk.SystemToolResponse\x12\x37\n\nGlobalVars\x12\x13.sdk.GlobalsRequest\x1a\x14.sdk.GlobalsResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SYSTEMTOOLREQUEST_ARGSENTRY']._loaded_options = None
  _globals['_SYSTEMTOOLREQUEST_ARGSENTRY']._serialized_options = b'8\001'
  _globals['_SYSTEMTOOLRESPONSE_RESULTSENTRY']._loaded_options = None
  _globals['_SYSTEMTOOLRESPONSE_RESULTSENTRY']._serialized_options = b'8\001'
  _globals['_GENERATEFINISHREASON']._serialized_start=3111
  _globals['_GENERATEFINISHREASON']._serialized_end=3263
  _globals['_TRUFFLETYPE']._serialized_start=3265
  _globals['_TRUFFLETYPE']._serialized_end=3340
  _globals['_MODELDESCRIPTION']._serialized_start=19
  _globals['_MODELDESCRIPTION']._serialized_end=444
  _globals['_MODELDESCRIPTION_CAPABILITIES']._serialized_start=215
  _globals['_MODELDESCRIPTION_CAPABILITIES']._serialized_end=342
  _globals['_MODELDESCRIPTION_MODELTYPE']._serialized_start=344
  _globals['_MODELDESCRIPTION_MODELTYPE']._serialized_end=444
  _globals['_GETMODELSREQUEST']._serialized_start=446
  _globals['_GETMODELSREQUEST']._serialized_end=464
  _globals['_GETMODELSRESPONSE']._serialized_start=466
  _globals['_GETMODELSRESPONSE']._serialized_end=524
  _globals['_GLOBALSREQUEST']._serialized_start=526
  _globals['_GLOBALSREQUEST']._serialized_end=585
  _globals['_GLOBALSRESPONSE']._serialized_start=587
  _globals['_GLOBALSRESPONSE']._serialized_end=619
  _globals['_SYSTEMTOOLREQUEST']._serialized_start=622
  _globals['_SYSTEMTOOLREQUEST']._serialized_end=753
  _globals['_SYSTEMTOOLREQUEST_ARGSENTRY']._serialized_start=710
  _globals['_SYSTEMTOOLREQUEST_ARGSENTRY']._serialized_end=753
  _globals['_SYSTEMTOOLRESPONSE']._serialized_start=756
  _globals['_SYSTEMTOOLRESPONSE']._serialized_end=927
  _globals['_SYSTEMTOOLRESPONSE_RESULTSENTRY']._serialized_start=871
  _globals['_SYSTEMTOOLRESPONSE_RESULTSENTRY']._serialized_end=917
  _globals['_SDKRESPONSE']._serialized_start=929
  _globals['_SDKRESPONSE']._serialized_end=984
  _globals['_TOOLUPDATEREQUEST']._serialized_start=986
  _globals['_TOOLUPDATEREQUEST']._serialized_end=1035
  _globals['_USERREQUEST']._serialized_start=1037
  _globals['_USERREQUEST']._serialized_end=1083
  _globals['_USERRESPONSE']._serialized_start=1085
  _globals['_USERRESPONSE']._serialized_end=1171
  _globals['_GENERATERESPONSEFORMAT']._serialized_start=1174
  _globals['_GENERATERESPONSEFORMAT']._serialized_end=1346
  _globals['_GENERATERESPONSEFORMAT_RESPONSEFORMAT']._serialized_start=1281
  _globals['_GENERATERESPONSEFORMAT_RESPONSEFORMAT']._serialized_end=1335
  _globals['_CONTENT']._serialized_start=1349
  _globals['_CONTENT']._serialized_end=1507
  _globals['_CONTENT_ROLE']._serialized_start=1429
  _globals['_CONTENT_ROLE']._serialized_end=1498
  _globals['_CONTEXT']._serialized_start=1509
  _globals['_CONTEXT']._serialized_end=1549
  _globals['_GENERATEREQUEST']._serialized_start=1552
  _globals['_GENERATEREQUEST']._serialized_end=1767
  _globals['_GENERATIONUSAGE']._serialized_start=1769
  _globals['_GENERATIONUSAGE']._serialized_end=1857
  _globals['_TOKENRESPONSE']._serialized_start=1860
  _globals['_TOKENRESPONSE']._serialized_end=2045
  _globals['_GENERATERESPONSE']._serialized_start=2048
  _globals['_GENERATERESPONSE']._serialized_end=2239
  _globals['_SORTEDEMBEDDING']._serialized_start=2241
  _globals['_SORTEDEMBEDDING']._serialized_end=2287
  _globals['_EMBEDRESPONSE']._serialized_start=2289
  _globals['_EMBEDRESPONSE']._serialized_end=2343
  _globals['_EMBEDREQUEST']._serialized_start=2345
  _globals['_EMBEDREQUEST']._serialized_end=2393
  _globals['_APPUPLOADPROGRESS']._serialized_start=2396
  _globals['_APPUPLOADPROGRESS']._serialized_end=3108
  _globals['_APPUPLOADPROGRESS_APPUPLOADERROR']._serialized_start=2635
  _globals['_APPUPLOADPROGRESS_APPUPLOADERROR']._serialized_end=2670
  _globals['_APPUPLOADPROGRESS_UPLOADSTEP']._serialized_start=2673
  _globals['_APPUPLOADPROGRESS_UPLOADSTEP']._serialized_end=2987
  _globals['_APPUPLOADPROGRESS_UPLOADTYPE']._serialized_start=2989
  _globals['_APPUPLOADPROGRESS_UPLOADTYPE']._serialized_end=3080
  _globals['_TRUFFLESDK']._serialized_start=3343
  _globals['_TRUFFLESDK']._serialized_end=3798
# @@protoc_insertion_point(module_scope)
